pub struct MacosEnumerationPage { /* private fields */ }Expand description
Owned, validated page returned to the Swift enumerator.
Implementations
Sourceimpl MacosEnumerationPage
impl MacosEnumerationPage
Sourcepub fn from_backend(
root_key: &CloudItemKey,
parent: &CloudItemKey,
page: CloudItemPage,
) -> Result<Self>
pub fn from_backend( root_key: &CloudItemKey, parent: &CloudItemKey, page: CloudItemPage, ) -> Result<Self>
Validates a backend page against the exact domain root and requested parent before exposing it to File Provider.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
Sourcepub fn items(&self) -> &[MacosFileProviderItem]
pub fn items(&self) -> &[MacosFileProviderItem]
Returns items in backend enumeration order.
Sourcepub fn into_parts(self) -> (Vec<MacosFileProviderItem>, Option<PageCursor>)
pub fn into_parts(self) -> (Vec<MacosFileProviderItem>, Option<PageCursor>)
Consumes the page into owned items and continuation cursor.