pub struct MacosExtensionRequestLease { /* private fields */ }Expand description
Non-cloneable ownership proof for one request accepted before closing.
Implementations
Sourceimpl MacosExtensionRequestLease
impl MacosExtensionRequestLease
Sourcepub fn generation(&self) -> SessionGeneration
pub fn generation(&self) -> SessionGeneration
Returns the generation that accepted the request.
Sourcepub fn accepts_completion(&self, session: &MacosExtensionSession) -> bool
pub fn accepts_completion(&self, session: &MacosExtensionSession) -> bool
Returns whether completion still belongs to the supplied extension instance.